@@ -11,21 +11,21 @@ namespace
 {
     Arg::LongOption longOptions[] = 
     {
-        Arg::LongOption("analyze-only", 'A'),
+        {"analyze-only", 'A'},
 
-        Arg::LongOption("baseclass-preinclude", 'H'),
-        Arg::LongOption("baseclass-skeleton", 'B'),
-        Arg::LongOption("class-skeleton", 'C'),
-        Arg::LongOption("implementation-skeleton", 'I'),
-        Arg::LongOption("parsefun-skeleton", 'P'),
-        Arg::LongOption("skeleton-directory", 'S'),
+        {"baseclass-preinclude", 'H'},
+        {"baseclass-skeleton", 'B'},
+        {"class-skeleton", 'C'},
+        {"implementation-skeleton", 'I'},
+        {"parsefun-skeleton", 'P'},
+        {"skeleton-directory", 'S'},
 
-        Arg::LongOption("baseclass-header", 'b'),
-        Arg::LongOption("class-header", 'c'),
-        Arg::LongOption("implementation-header", 'i'),
-        Arg::LongOption("parsefun-source", 'p'),
+        {"baseclass-header", 'b'},
+        {"class-header", 'c'},
+        {"implementation-header", 'i'},
+        {"parsefun-source", 'p'},
 
-        Arg::LongOption("class-name", Arg::Required),
+        {"class-name", Arg::Required},
 
         Arg::LongOption("construction"),
                 // implies verbose, but also shows FIRST and FOLLOW sets as
@@ -33,48 +33,50 @@ namespace
                 // items
 
         Arg::LongOption("debug"),
-
         Arg::LongOption("error-verbose"),
 
-        Arg::LongOption("filenames", 'f'),
+        {"filenames", 'f'},
 
         Arg::LongOption("force-implementation-header"),
         Arg::LongOption("force-class-header"),
-
         Arg::LongOption("insert-stype"),
 
-        Arg::LongOption("help", 'h'),
-        Arg::LongOption("include-only"),
-        Arg::LongOption("max-inclusion-depth", Arg::Required),
+        {"help", 'h'},
 
-        Arg::LongOption("namespace", 'n'),
+        Arg::LongOption("include-only"),
+
+        {"max-inclusion-depth", Arg::Required},
+        {"namespace", 'n'},
 
         Arg::LongOption("no-baseclass-header"),
         Arg::LongOption("no-parse-member"),
 
-        Arg::LongOption("lines", 'l'),
+        {"lines", 'l'},
+
         Arg::LongOption("no-lines"),
 
-        Arg::LongOption("required-tokens", Arg::Required),
+        {"print", Arg::Required},
+        {"required-tokens", Arg::Required},
+        {"scanner", 's'},
 
-        Arg::LongOption("scanner", 's'),
         Arg::LongOption("scanner-debug"),
 
+        {"scanner-token-function", Arg::Required},
+
         Arg::LongOption("show-filenames"),
                 // writes the names of the files to the standard output
 
         Arg::LongOption("thread-safe"),
                 // no static data are modified, making bisonc++ thread-safe
 
-        Arg::LongOption("usage", 'h'),
-        Arg::LongOption("version", 'v'),
-        Arg::LongOption("verbose", 'V'),
+        {"usage", 'h'},
+        {"version", 'v'},
+        {"verbose", 'V'},
                 // shows rules, tkoens, final states and kernel items, 
                 // and describes conflicts when found
     };
-
-    Arg::LongOption const *const longEnd = longOptions + 
-                                sizeof(longOptions) / sizeof(Arg::LongOption); 
+    auto longEnd = longOptions + 
+                               sizeof(longOptions) / sizeof(Arg::LongOption);  
 }
 
 int main(int argc, char **argv)
@@ -110,7 +112,6 @@ try
     rules.determineFollow();
     rules.showFollow();
 
-
                             // define the startproduction
     Production::setStart(rules.startProduction());
 
@@ -140,8 +141,6 @@ try
     generator.implementationHeader();
 
     generator.parseFunction();
-
-    return 0;
 }
 catch(Errno const &err)
 {
