@@ -5,11 +5,13 @@
 #include <vector>
 #include <string>
 
-class Block: public std::string
+class Block: private std::string
+
 {
     size_t  d_line;
-    std::string d_source;
-
+    std::string d_source;               // the source in which the block 
+                                        // was found. The block's text itself
+                                        // is in the Block's base class
     int     d_count;
     
     public:
@@ -41,7 +43,24 @@ class Block: public std::string
         std::vector<Range>::const_reverse_iterator skipRbegin() const;
         std::vector<Range>::const_reverse_iterator skipRend() const;
         size_t line() const;
-        std::string const &source() const;
+        std::string const &source() const;  // the block's source file
+        std::string const &str() const;     // the block's contents
+
+        void beginSkip();               // begins a new skip-area
+        bool endSkip(char const *text); // if a block, text is added and
+                                        // the current skip-area is ended
+        bool skip(char const *text);    // if a block, text is added and
+                                        // added to the skip-areas
+
+        using std::string::empty;
+        using std::string::find_first_of;
+        using std::string::find_last_of;
+        using std::string::substr;
+        using std::string::find;
+        using std::string::length;
+
+        using std::string::replace;
+        using std::string::operator[];
 };
 
 inline Block::Block()
@@ -54,6 +73,11 @@ inline void Block::operator+=(char const *text)
     append(text);
 }
 
+inline void Block::beginSkip()
+{
+    d_skip.push_back({length(), 0});
+}
+
 inline Block::operator bool() const
 {
     return d_count;
@@ -64,6 +88,7 @@ Block::skipRbegin() const
 {
     return d_skip.rbegin();
 }
+
 inline std::vector<Block::Range>::const_reverse_iterator 
 Block::skipRend() const
 {
@@ -77,6 +102,10 @@ inline std::string const &Block::source() const
 {
     return d_source;
 }
+inline std::string const &Block::str() const
+{
+    return *this;
+}
 
 #endif
 
