@@ -56,7 +56,7 @@ class Parser: public ParserBase
 
         void error(char const *msg)
         {
-            std::cerr << msg << std::endl;
+            std::cerr << msg << '\n';
         }
 
         int lex()
