@@ -6,29 +6,18 @@
 #include "../firstset/firstset.h"
 #include "../terminal/terminal.h"
 
-class FollowSet: public std::set<Terminal const *>
+class FollowSet
 {
     friend std::ostream &operator<<(std::ostream &out, FollowSet const &fSet);
 
     bool d_EOF;             // true if {Follow} contains EOF
+    std::set<Terminal const *> d_set;
 
     public:
-        FollowSet()
-        :
-            d_EOF(false)
-        {}
-        size_t setSize() const
-        {
-            return size() + d_EOF;
-        }
-        void setEOF()
-        {
-            d_EOF = true;
-        }
-        bool hasEOF() const
-        {
-            return d_EOF;
-        }
+        FollowSet();
+        size_t setSize() const;
+        void setEOF();
+        bool hasEOF() const;
         FollowSet &operator+=(FollowSet const &other);
         FollowSet &operator+=(FirstSet const &firstSet);
 
@@ -36,6 +25,26 @@ class FollowSet: public std::set<Terminal const *>
         std::ostream &oInsert(std::ostream &out) const;
 };
 
+inline FollowSet::FollowSet()
+:
+    d_EOF(false)
+{}
+
+inline size_t FollowSet::setSize() const
+{
+    return d_set.size() + d_EOF;
+}
+
+inline void FollowSet::setEOF()
+{
+    d_EOF = true;
+}
+
+inline bool FollowSet::hasEOF() const
+{
+    return d_EOF;
+}
+
 inline std::ostream &operator<<(std::ostream &out, FollowSet const &followSet)
 {
     return followSet.oInsert(out);
