@@ -12,7 +12,7 @@ void Generator::classHeader() const
     (
         access(d_parser.classHeader().c_str(), F_OK) == 0
         &&
-        not Arg::instance().option(0, "force-class-header")
+        not d_arg.option(0, "force-class-header")
     )
         return;
 
