@@ -27,21 +27,27 @@ class Generator
 
     std::string d_baseclassScope;
     std::string const &d_nameSpace;
+    std::string const *d_matchedTextFunction;
+    std::string const *d_scannerTokenFunction;
 
     mutable std::string d_key;          // extracted at $insert statements
     mutable size_t d_indent;
 
     mutable std::string d_line;
     bool d_debug;
-
+    bool d_print;
+    
     mutable Writer d_writer;                // maintains its own const-ness
 
-    static MapValue s_mapValues[];
     static Map s_insert;
     static char const *s_baseFlag;          // text to change to the class 
                                             // name
     static size_t const s_baseFlagSize;     // # of characters in s_baseFlag
 
+    static std::string s_matchedTextFunction;   // default way to call the
+    static std::string s_scannerTokenFunction;  // scanner's token en text
+                                                // functions.
+
     public:
         Generator(Rules const &rules, Parser const &parser);
 
@@ -78,6 +84,7 @@ class Generator
         void namespaceOpen(std::ostream &out) const;
         void namespaceUse(std::ostream &out) const;
         void preIncludes(std::ostream &out) const;
+        void print(std::ostream &out) const;
         void requiredTokens(std::ostream &out) const;
         void scannerH(std::ostream &out) const;
         void scannerObject(std::ostream &out) const;
@@ -88,7 +95,6 @@ class Generator
 
         static void selectSymbolic(Terminal const *terminal, 
                                    Terminal::ConstVector *symbolicTokens);
-                                   
 };
 
 #endif
