@@ -4,13 +4,13 @@
 #include <iosfwd>
 #include <vector>
 
-#include "../srsolution/srsolution.h"
+#include "../enumsolution/enumsolution.h"
 #include "../statetype/statetype.h"
 #include "../symbol/symbol.h"
 #include "../item/item.h"
 #include "../stateitem/stateitem.h"
 
-class Next: public StateType, public SRSolution
+class Next
 {
     friend std::ostream &operator<<(std::ostream &out, Next const &next);
 
@@ -18,9 +18,13 @@ class Next: public StateType, public SRSolution
     size_t d_next;
     std::vector<size_t> d_kernel;
 
+    StateType d_stateType;
+
     static std::ostream &(Next::*s_insertPtr)(std::ostream &out) const;
 
     public:
+        typedef Enum::Solution Solution;
+
         typedef std::vector<Next>       Vector;
         typedef Vector::iterator        Iterator;
         typedef Vector::const_iterator  ConstIter;
