@@ -49,12 +49,14 @@ class Parser: public ParserBase
     std::string d_implementationHeader;
     std::string d_implementationSkeleton;
     std::string d_locationDecl;
+    std::string d_matchedTextFunction;      // set by --print or %print
     std::string d_msg;
     std::string d_nameSpace;
     std::string d_parsefunSkeleton;
     std::string d_parsefunSource;
     std::string d_preInclude;
     std::string d_scannerInclude;
+    std::string d_scannerTokenFunction;
     std::string d_stackDecl;
     std::string d_verboseName;
 
@@ -102,12 +104,14 @@ class Parser: public ParserBase
         bool lines() const;
         bool lspNeeded() const;
         std::string const &ltype() const;
+        std::string const &matchedTextFunction() const;
         std::string const &nameSpace() const;
         std::string const &parseSkeleton() const;
         std::string const &parseSource() const;
         std::string const &preInclude() const;
         size_t requiredTokens() const;
         std::string const &scanner() const;
+        std::string const &scannerTokenFunction() const;
         std::string const &stype() const;
 
     private:
@@ -170,6 +174,7 @@ class Parser: public ParserBase
         void setClassHeader(int type);
         void setClassName();
         void setPreInclude();
+        void setPrint();
         void setDebugFlag();
         void setErrorVerbose();
         void setExpectedConflicts();
@@ -186,6 +191,7 @@ class Parser: public ParserBase
         void setPrecedence(int type);
         void setRequiredTokens();
         void setScannerInclude();
+        void setScannerTokenFunction();
         void setStart();
         void setStype();
 
@@ -224,6 +230,9 @@ inline int Parser::lex()
     return d_scanner.yylex();
 }
 
+inline void Parser::print()
+{}
+
 inline std::string const &Parser::baseclassHeader() const
 {
     return d_baseclassHeader;
@@ -282,6 +291,10 @@ inline std::string const &Parser::ltype() const
 {
     return d_locationDecl;
 }
+inline std::string const &Parser::matchedTextFunction() const
+{
+    return d_matchedTextFunction;
+}
 inline std::string const &Parser::nameSpace() const
 {
     return d_nameSpace;
@@ -307,6 +320,11 @@ inline std::string const &Parser::scanner() const
     return d_scannerInclude;
 }
 
+inline std::string const &Parser::scannerTokenFunction() const
+{
+    return d_scannerTokenFunction;
+}
+
 inline void Parser::setBaseclassHeader(int type)
 {
     definePathname(&d_baseclassHeader, type);
@@ -322,6 +340,11 @@ inline void Parser::setPreInclude()
     validateInclude(&d_preInclude);
 }
 
+inline void Parser::setPrint()
+{
+    definePathname(&d_matchedTextFunction, 1);        // remove "s 
+}
+
 inline void Parser::setDebugFlag()
 {
     d_debugFlag = true;
@@ -371,25 +394,23 @@ inline size_t Parser::requiredTokens() const
 {
     return d_requiredTokens;
 }
-
 inline void Parser::setScannerInclude()
 {
     validateInclude(&d_scannerInclude);
 }
-
+inline void Parser::setScannerTokenFunction()
+{
+    definePathname(&d_scannerTokenFunction, 0);
+}
 inline std::string const &Parser::stype() const
 {
     return d_stackDecl;
 }
-
 inline std::string *Parser::newYYText() const
 {
     return new std::string(d_scanner.YYText());
 }
 
-inline void Parser::print()      // use d_token, d_loc
-{}
-
 inline size_t Parser::nComponents(int nElements)
 {
     return nElements >= 0 ? nElements : -nElements - 1;
