@@ -8,7 +8,7 @@ void Parser::setLocationDecl()
     if (d_locationDecl.size())
         lineMsg() << "%location-struct or %ltype multiply specified" << err;
     
-    (d_locationDecl = "struct LTYPE__\n" + d_scanner.block()) += ";\n";
+    (d_locationDecl = "struct LTYPE__\n" + d_scanner.block().str()) += ";\n";
 
     d_lspNeeded = true;
 }
