@@ -8,7 +8,7 @@ void Parser::setUnionDecl()
     if (d_stackDecl.size())
         lineMsg() << "%union or %stype multiply specified" << err;
 
-    (d_stackDecl = "union STYPE__\n" + d_scanner.block()) += ";\n";
+    (d_stackDecl = "union STYPE__\n" + d_scanner.block().str()) += ";\n";
 
     d_unionDeclared = true;         // if a %union is used, then the rules
                                     // MUST have an associated return type if
