@@ -10,13 +10,13 @@
 #include "../symbol/symbol.h"
 #include "../terminal/terminal.h"
 
-#include <iostream>
-
 // NOTE: To obtain all productions of a certain Non-Terminal, use
 //       NonTerminal's `productions()' member
 
-class Production: public std::vector<Symbol *>
+class Production: private std::vector<Symbol *>
 {
+    typedef std::vector<Symbol *> Inherit;
+
     friend std::ostream &operator<<(std::ostream &out, 
                                                Production const *production);
     private:
@@ -33,6 +33,13 @@ class Production: public std::vector<Symbol *>
         static Production const *s_startProduction;
     
     public:
+        using Inherit::size;
+        using Inherit::begin;
+        using Inherit::end;
+        using Inherit::rbegin;
+        using Inherit::rend;
+        using Inherit::push_back;
+
         typedef std::vector<Production *>       Vector;
         typedef std::vector<Production const*>  ConstVector;
         typedef ConstVector::const_iterator     ConstIter;
@@ -53,24 +60,12 @@ class Production: public std::vector<Symbol *>
         void setPrecedence(Terminal const *terminal);
 
         static Production const *start();
-
-        struct IAContext                    // insertActionContext
-        {
-            std::ostream &out;
-            bool lineDirectives;
-            size_t indent;
-        };
-        static void insertAction(Production const *prod, IAContext &context);
+        static void insertAction(Production const *prod, std::ostream &out,
+                                 bool lineDirectives, size_t indent);
 
         static void setStart(Production const *production);
-
-        struct TermToNontermContext
-        {
-            Symbol *terminal;
-            Symbol *nonTerminal;
-        };
-        static void termToNonterm(Production *pPtr, 
-                                  TermToNontermContext &t2n);
+        static void termToNonterm(Production *pPtr, Symbol *terminal, 
+                                                    Symbol *nonTerminal);
 
         static void unused(Production const *production);
         static bool notUsed();
@@ -157,9 +152,9 @@ inline bool isTerminal(Symbol const *symbol)
 }
 
 inline void Production::termToNonterm(Production *pPtr, 
-                                      TermToNontermContext &t2n)
+                                      Symbol *terminal, Symbol *nonTerminal)
 {
-    std::replace(pPtr->begin(), pPtr->end(), t2n.terminal, t2n.nonTerminal);
+    std::replace(pPtr->begin(), pPtr->end(), terminal, nonTerminal);
 }
 
 #endif
