@@ -12,8 +12,7 @@ void Scanner::pushSource(yy_buffer_state *current, size_t size)
 
     recursiveInclusion();
     d_fileInfo.push_back(FileInfo(d_nextSource, yylineno));
-
-    ifstream *newStream = new ifstream(d_nextSource.c_str());
+    ifstream *newStream = d_fileInfo.back().d_in;
 
     if (!*newStream)
         lineMsg() << "Can't read `" << d_nextSource << "'" << fatal;
@@ -21,7 +20,6 @@ void Scanner::pushSource(yy_buffer_state *current, size_t size)
     d_state.push(current);
 
     yylineno = 1;                   // start counting lines at 1
-
     yy_switch_to_buffer(yy_create_buffer(newStream, size));
 
     d_include = false;              // %include processed
