@@ -3,20 +3,22 @@
 void SRConflict::processShiftReduceConflict(Next::ConstIter const &next, 
                                             size_t itemIdx)
 {
+    typedef Enum::Solution Solution;
+
     Solution solution =
             next->solveByPrecedence(d_itemVector[itemIdx].precedence());
 
-    if (solution == UNDECIDED)
+    if (solution == Solution::UNDECIDED)
         solution = next->solveByAssociation();
     
     bool forced = false;
     switch (solution)
     {
-        case REDUCE:
+        case Solution::REDUCE:
             d_rmShift.push_back(next - d_nextVector.begin());
         return;
 
-        case UNDECIDED:
+        case Solution::UNDECIDED:
             forced = true;
             ++s_nConflicts;
         break;
@@ -28,4 +30,3 @@ void SRConflict::processShiftReduceConflict(Next::ConstIter const &next,
     d_rmReduction.push_back(RmReduction(itemIdx, next->next(), 
                                         next->symbol(), forced));
 }
-
