@@ -8,8 +8,7 @@ size_t State::findKernel(Item::Vector const &searchKernel) const
     return  find_if
             (
                 s_state.begin(), s_state.end(),
-                FnWrap1c<State const *, Item::Vector const &, bool>
-                (hasKernel, searchKernel)
+                FnWrap::unary(hasKernel, searchKernel)
             )
             - s_state.begin();
 }
