@@ -75,8 +75,6 @@ class Terminal: public Symbol
 
         Precedence comparePrecedence(Terminal const *other) const;
         size_t precedence() const;
-        size_t value() const;
-        virtual FirstSet const &firstSet() const;
         void setLiteral(std::string const &literal);
         void setValue(size_t value);  // reassign a token value
         void setPrecedence(size_t value);
@@ -115,19 +113,18 @@ class Terminal: public Symbol
                                     // Values or names (of reserved tokens)
         std::ostream &nameOrValue(std::ostream &out) const;
 
-    protected:
+    private:
+        virtual FirstSet const &v_firstSet() const;
+        virtual size_t v_value() const;
         virtual std::ostream &insert(std::ostream &out) const;
 };
 
-namespace std
+inline std::ostream &operator<<(std::ostream &out, 
+          std::ostream &(Terminal::*insertPtr)(std::ostream &out) const)
 {
-    inline ostream &operator<<(ostream &out, 
-              ostream &(Terminal::*insertPtr)(ostream &out) const)
-    {
-        Terminal::inserter(insertPtr);
-        return out;
-    }
-}       
+    Terminal::inserter(insertPtr);
+    return out;
+}
 
 inline std::ostream &Terminal::plainName(std::ostream &out) const
 {
@@ -178,12 +175,12 @@ inline size_t Terminal::precedence() const
     return d_precedence;
 }
 
-inline size_t Terminal::value() const
+inline size_t Terminal::v_value() const
 {
     return d_value;
 }
 
-inline FirstSet const &Terminal::firstSet() const
+inline FirstSet const &Terminal::v_firstSet() const
 {
     return d_firstSet;
 }        
