@@ -6,11 +6,11 @@ void Writer::insert(Terminal::ConstVector const &tokens) const
             "    // Symbolic tokens:\n"
             "    enum Tokens__\n"
             "    {\n";
- 
-    TokenContext context = {0, *d_out};
+
+    size_t lastTokenValue = 0;
 
     for_each(tokens.begin(), tokens.end(),
-        FnWrap1c<Terminal const *, TokenContext &>(insert, context));
+        FnWrap::unary(insertToken, lastTokenValue, *d_out));
 
     *d_out <<  "    };\n"
            "\n";
